function sampleCommunity(Community,nReads)

% Allow debugging commands
global Debug ReCompute;
if isempty(Debug)
    Debug = 0;
elseif Debug == 1
    fprintf('Debug Mode On\n');
end
if isempty(ReCompute)
  ReCompute=0;
end

if (ischar(nReads))
    nReads = str2double(nReads);
end

if ~ exist(Community,'dir')
    sprintf('Community %s does not exist!',Community)
    return
end

% Make the Samples directory if it does not exist
fileName = sprintf('%s/Reads',Community);
if ~ exist(fileName,'dir')
    mkdir(fileName);
else
  if ~ ReCompute
    fprintf('Samples found for %s. Aborting.\n', Community);
    return;
  end
end

% Read in the parameters
fileName = sprintf('%s/Parameters.mat',Community);
load(fileName, 'nGenes', 'nOTUs', 'nSamples', 'geneMinLength', 'geneMaxLength', 'doublingProb', 'RelativeAbundance', 'varAbundance', 'MinOTUSize', 'ConstantGeneLength');

if Debug
    fprintf('Community has %d genes and %d Samples\n', nGenes, nOTUs);
end

% --- Load Communities --- % 

fileName = sprintf('%s/SampleGenes.mat',Community);
FH = fopen(fileName, 'r');
cGenes = fread(FH,[nSamples,nGenes],'double');
fclose(FH);

% --- Read from each Sample --- %

fprintf('Reading %d times from Sample', nReads)
for i=1:nSamples

    fprintf(' %d', i)
    if mod(i,25) == 0 && i ~= 0
        fprintf('\n')
    end
    
    % sample is a list of all the genes
    sample = zeros(1,nGenes);
    
    % Set a random list
    GenomeSize = sum(cGenes(i,:));
    Reads=sort(GenomeSize*rand(1, nReads));
    
    Weights = cGenes(i,:);
    % Weight the Community's genes
    for j=2:nGenes
        Weights(j) = Weights(j) + Weights(j-1);
    end

    if Debug
        fprintf('\nGenomeSize=%f, Weights(nGenes)=%f\n', GenomeSize, Weights(nGenes));
    end

    
    gene = 1;
    for n=1:length(Reads)
        while Reads(n) > Weights(gene)
            gene = gene +1;
        end
        if Debug
            fprintf('sample=%d, read=%f, pointer=%d, weight=%f\n', n, Reads(n), gene, Weights(gene));
        end
        sample(gene) = sample(gene) + 1;
    end
    
    fileName = sprintf('%s/Reads/Sample%d_1.mat',Community,i);
    FH = fopen(fileName, 'w');
    fwrite(FH,sample,'double');
    fclose(FH);
    
    fileName = sprintf('%s/Reads/Sample%d_1.txt',Community,i);
    FH = fopen(fileName,'w');
    for n=1:length(sample)
        fprintf(FH,'%d\t%d\n',n,sample(n));
    end
    fclose(FH);
end

fprintf('\n')



end