package Lookup;
use strict;
require Exporter;

our @ISA = qw(Exporter);

our @EXPORT_OK = qw( createLookupTable createLookupWeights createLookupTableWeighted createTripletLookupTable );

sub createLookupTable {
  my $file=shift;
  my $key=shift;
  my $value=shift;
  my $multiple=shift;

  my %l;

  unless ( defined $file && defined $key && defined $value ) {
    print "Lookup.pm - createLookupTable: file key-column value-column multiple\n";
    return \%l;
  }
  
  unless ( -e $file ) {
    print "Lookup.pm - createLookupTable: \"$file\" does not exist.\n";
    return \%l;
  }
  
  unless ( $key =~ /^\d+$/ && $value =~ /^\d+$/ ) {
    print "Lookup.pm - createLookupTable: key and value must be integers.\n";
    return \%l;
  }
  
  unless (defined $multiple) {
    $multiple=0;
  }


  if ($file =~ /gz$/) {
    $file = "zcat $file |";
  }
  open (FH, $file) or die "Cannot read $file\n";

  while (<FH>) {
    chomp;
    
    next if (/^#/);
    
    my ($entry,$aspect) = (split(/\t/))[$key,$value];
    
    unless (defined $entry && defined $aspect) {
      print "Can't read $_\n";
      next;
    }
    
    if ( $multiple ) {
      push @{$l{$entry}}, $aspect;
    } else {
      $l{$entry} = $aspect;
    }
    
  }
  close(FH);

  return \%l;
}

sub createLookupWeights {
  my %l;

  my $table = shift;

  unless ( defined $table ) {
    print "Lookup.pm - createLookupWeights: lookup-table\n";
    return \%l;
  }
  
  foreach my $key (keys %{$table}) {
    if ( ref($table->{$key}) eq 'ARRAY' ) {
      my $weight = 1/(scalar @{$table->{$key}});
      foreach my $entry (@{$table->{$key}}) {
	$l{$key}->{$entry}+=$weight;
      }
    } else {
      $l{$key}->{$table->{$key}}=1;
    }
    
  }
  
  return \%l;
}

sub createLookupTableWeighted {
  my $file=shift;
  my $key=shift;
  my $value=shift;
  my $weight=shift;
  
  unless (defined $key) {
    $key = 0;
  }
  unless (defined $value) {
    $value = 1;
  }
  unless (defined $weight) {
    $weight = 2;
  }

  my %l;

  unless ( defined $file ) {
    print "Lookup.pm - createLookupTable: file key-column value-column weight-column\n";
    return \%l;
  }
  
  unless ( -e $file ) {
    print "Lookup.pm - createLookupTable: \"$file\" does not exist.\n";
    return \%l;
  }
  
  unless ( $key =~ /^\d+$/ && $value =~ /^\d+$/ && $weight =~ /^\d+$/ ) {
    print "Lookup.pm - createLookupTable: key, value, and weight columns must be integers.\n";
    return \%l;
  }
  
  if ($file =~ /gz$/) {
    $file = "zcat $file |";
  }
  open (FH, $file) or die "Cannot read $file\n";

  while (<FH>) {
    chomp;
    
    next if (/^#/);
    
    my ($entry,$aspect,$amount) = (split(/\t/))[$key,$value,$weight];
    
    unless (defined $entry && defined $aspect && $amount) {
      print "Can't read $_\n";
      next;
    }
    
    $l{$entry}->{$aspect}+=$amount;
    
  }
  close(FH);

  return \%l;
}


sub createTripletLookupTable {
  my $file=shift;
  my $key1=shift;
  my $key2=shift;
  my $value=shift;
  my $multiple=shift;

  my %l;

  unless ( defined $file && defined $key1 && defined $key2 && defined $value ) {
    print "Lookup.pm - createLookupTable: file key1-column key2-column value-column multiple\n";
    return \%l;
  }
  
  unless ( -e $file ) {
    print "Lookup.pm - createLookupTable: \"$file\" does not exist.\n";
    return \%l;
  }
  
  unless ( $key1 =~ /^\d+$/ && $key2 =~ /^\d+$/ && $value =~ /^\d+$/ ) {
    print "Lookup.pm - createLookupTable: keys and value must be integers.\n";
    return \%l;
  }
  
  unless (defined $multiple) {
    $multiple=0;
  }


  if ($file =~ /gz$/) {
    $file = "zcat $file |";
  }
  open (FH, $file) or die "Cannot read $file\n";

  while (<FH>) {
    chomp;
    
    next if (/^#/);
    
    my ($entry1,$entry2,$aspect) = (split(/\t/))[$key1,$key2,$value];
    
    unless (defined $entry1 && defined $entry2 && defined $aspect) {
      print "Can't read $_\n";
      next;
    }
    
    if ( $multiple ) {
      push @{$l{$entry1}->{$entry2}}, $aspect;
    } else {
      $l{$entry1}->{$entry2} = $aspect;
    }
    
  }
  close(FH);

  return \%l;
}


1;
